@@ -16,7 +16,6 @@ AsyncHTTPSubmitTest::AsyncHTTPSubmitTest(QCoreApplication& app)
   using namespace KCDDB;
 
   client_ = new Client;
-  client_->config().setFreedbSubmitTransport(Submit::HTTP);
   client_->setBlockingMode( false );
 
   TrackOffsetList list;
@@ -68,3 +67,5 @@ int main(int argc, char ** argv)
 
   return app.exec();
 }
+
+#include "moc_asynchttpsubmittest.cpp"
